
# AlphaESSCloud
This module integrates the Alpha ESS inverty and batteries via the Alpha ESS Cloud API

Special thanks to CharlesGillandres for the API wrapper https://github.com/CharlesGillanders/alphaess-openAPI

## Setup

 - Register at https://open.alphaess.com/ to get your Developer ID (appID) and App secret (appSecret).

 - Register your inverter (and battery) to the account

 
## Usage
```
Usage: define myAlphaESSCloud fhempy alphaesscloud appID appSecret serial
```

appID: your developer ID
appSecret: the app key you created
serial: the SN of the inverter to monitor

